====================
cubicweb.ajax.box.js
====================
.. module:: cubicweb.ajax.box.js

Functions for ajax boxes.

 :organization: Logilab
 :copyright: 2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr